@@ -3,22 +3,11 @@
 #
 
 import fire
-import os
 import configparser
-import prompt_toolkit
-from prompt_toolkit import styles
-from prompt_toolkit import formatted_text
 import pathlib
 
 __all__ = ["CLI"]
 
-PROMPT_STYLE = styles.Style.from_dict(
-    {
-        # Prompt.
-        "main": "ansibrightyellow",
-    }
-)
-
 
 class CLI:
     def init(self, api_key: str = None):
@@ -32,14 +21,6 @@ class CLI:
 
         :param api_key: your Pinecone API key
         """
-        # Prompt for inputs
-        session = prompt_toolkit.PromptSession()
-        if not api_key:
-            api_key = session.prompt(
-                formatted_text.HTML("<main>Pinecone API key: </main>"),
-                style=PROMPT_STYLE,
-                default=os.getenv("PINECONE_API_KEY", ""),
-            )
         # Construct config
         config = configparser.ConfigParser()
         config["default"] = {
