@@ -3,8 +3,10 @@
 #
 
 from pinecone.functions import Function
+from pinecone.utils.constants import NODE_TYPE_RESOURCES
 from abc import abstractmethod
-from typing import Dict, Union, Optional
+from typing import Dict, Optional
+
 
 class Engine(Function):
 
@@ -19,17 +21,21 @@ class Engine(Function):
     def size(self) -> int:
         raise NotImplementedError
 
-    def get_stats(self) -> Dict[str, Union[int, float, str]]:
+    def get_stats(self) -> Dict:
         return {'size': self.size()}
 
+    @property
+    def stats_frequency_seconds(self):
+        return 60
+
     @property
     def memory_request(self) -> int:
-        # keep request close to 4GB limits
-        # 2 GB (1GB of data) + 1 GB of metadata in future
-        return 3750
+        return NODE_TYPE_RESOURCES[self._node_type]['memory']
+
+    @property
+    def cpu_request(self) -> int:
+        return NODE_TYPE_RESOURCES[self._node_type]['cpu']
 
     @property
     def volume_request(self) -> Optional[int]:
-        return 15
-
-
+        return NODE_TYPE_RESOURCES[self._node_type]['disk']
