@@ -302,9 +302,9 @@ class WALServlet(ZMQServlet):
         for offset, entry in self.sync_replay_log(self.get_offset(self.replica)):
             try:
                 handler(entry)  # type: core_pb2.Request
-                self.sync_ack(offset)
-            except Exception as e:
-                logger.error(e)
+            except Exception as e:  # ignore messages that fail
+                logger.info(f'Error handling msg while recovering from WAL. offset: {offset} error: {e}')
+            self.sync_ack(offset)
 
     def swap_log_files(self, end_file_offset: int):
         tmp_log_file = open(self.tmp_log_path, "r+b")
