@@ -109,7 +109,8 @@ class ZMQService(Runnable):
     async def run_handler_in_executor(self, msg: 'core_pb2.Request'):
         loop = asyncio.get_event_loop()
         if self.executor is None:
-            self.executor = concurrent.futures.ThreadPoolExecutor(max_workers=1)
+            max_workers = int(os.environ.get('PINECONE_HANDLER_WORKERS', 1))
+            self.executor = concurrent.futures.ThreadPoolExecutor(max_workers=max_workers)
         try:
             result = await run_in_executor(loop, self.executor, self.function.handle_msg, msg)
             return result
@@ -154,7 +155,9 @@ class ZMQService(Runnable):
 
         entrypoints.start(servlet_spec, volume_request=self.volume_request,
                           persistent_dir=os.path.join(self.function.default_persistent_dir, 'wal'),
-                          num_replicas=self.replicas, sync_handler=self.function.handle_msg)
+                          num_replicas=self.replicas, sync_msg_handler=self.function.handle_msg,
+                          stats_exporter=self.function.export_stats)
+
 
     def cleanup(self):
         self.function.cleanup()
